# REQUest REcording

Requre \[rekure\]

Is Library for storing output of various function and methods to
persistent storage and be able to replay the stored output to functions
back

[Documentation](https://requre.readthedocs.io/en/latest/)

## Plan and current status

- Used for testing [packit-service](https://github.com/packit-service) organization projects
  - ogr
  - packit
